PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/NavImage.hpp File Reference

PCB Environment 2

Loading...
Searching...
No Matches
Data Structures | Macros
NavImage.hpp File Reference
`#include "Rasterizer.hpp"`

Go to the source code of this file.

## Data Structures
struct | NavPixel< chan_t >
class | NavImage< chan_t >

## Macros
#define | NAV_IMAGE_NUM_CHANS 8
#define | NAV_IMAGE_CHAN_TRACK_T 0
#define | NAV_IMAGE_CHAN_TRACK_B 3
#define | NAV_IMAGE_CHAN_TRACK_M 6
#define | NAV_IMAGE_CHAN_PIN_T 1
#define | NAV_IMAGE_CHAN_PIN_B 4
#define | NAV_IMAGE_CHAN_RATSNEST_T 2
#define | NAV_IMAGE_CHAN_RATSNEST_B 5
#define | NAV_IMAGE_CHAN_VIA 7

## Macro Definition Documentation

## ◆ NAV_IMAGE_CHAN_PIN_B

#define NAV_IMAGE_CHAN_PIN_B 4

## ◆ NAV_IMAGE_CHAN_PIN_T

#define NAV_IMAGE_CHAN_PIN_T 1

## ◆ NAV_IMAGE_CHAN_RATSNEST_B

#define NAV_IMAGE_CHAN_RATSNEST_B 5

## ◆ NAV_IMAGE_CHAN_RATSNEST_T

#define NAV_IMAGE_CHAN_RATSNEST_T 2

## ◆ NAV_IMAGE_CHAN_TRACK_B

#define NAV_IMAGE_CHAN_TRACK_B 3

## ◆ NAV_IMAGE_CHAN_TRACK_M

#define NAV_IMAGE_CHAN_TRACK_M 6

## ◆ NAV_IMAGE_CHAN_TRACK_T

#define NAV_IMAGE_CHAN_TRACK_T 0

## ◆ NAV_IMAGE_CHAN_VIA

#define NAV_IMAGE_CHAN_VIA 7

## ◆ NAV_IMAGE_NUM_CHANS

#define NAV_IMAGE_NUM_CHANS 8